This is unreleased documentation for Yew Next version.
For up-to-date documentation, see the latest version on docs.rs.

flush

Function flush 

pub async fn flush()
Available on (crate features test) and not (WebAssembly and non-WASI and non-crate feature not_browser_env) only.
Flush all pending scheduler work, ensuring all rendering and lifecycle callbacks complete.

On non-browser targets, the scheduler runs synchronously so this simply drains pending work.